/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#include <iostream> // DEBUG
#include <set>
#include <stdlib.h> // DEBUG

#include <BlinkenLib/BlinkenFrame.h>

#include "Stream.h"
#include "StreamRecv.h"

namespace Blinker {

/// constructor
Stream::Stream()
{
}

/// virtual destructor
Stream::~Stream()
{
}

/**
 * @brief attach a stream receiver
 * @param[in] recv stream receiver to attach
 */
void Stream::attach(StreamRecv *recv)
{
  m_recvs.insert(recv);
}

/**
 * @brief detach a stream receiver
 * @param[in] recv stream receiver to detach
 */
void Stream::detach(StreamRecv *recv)
{
  m_recvs.erase(recv);
}

/**
 * @brief set current frame
 * @param[in] pFrame current frame
 */
void Stream::setFrame(stBlinkenFrame *pFrame)
{
  // DEBUG
  char *str = BlinkenFrameToString(pFrame);
  std::cout << str;
  free(str);

  // pass frame to all receivers
  Recvs::iterator it;
  for (it = m_recvs.begin(); it != m_recvs.end(); ++it)
    (*it)->setFrame(pFrame);
}

/// set current frame to none
void Stream::setNoFrame()
{
  // DEBUG
  std::cout << "no frame" << std::endl;

  // pass "no frame" to all receivers
  Recvs::iterator it;
  for (it = m_recvs.begin(); it != m_recvs.end(); ++it)
    (*it)->setNoFrame();
}

} // namespace Blinker

